# PictureCombiner
 图片拼接功能
 <br>
有两种拼接方式及两种拼接方法，
 <br>
 拼接方式：文件夹拼接DirCombine，文件拼接PicCombine
 <br>
 拼接方法：水平拼接，垂直拼接
 <br>
 拼接参数可根据拼接结果进行调整，默认配置在测试中表现良好，但不保证可应对任意情况
 <br>
 （可选）和MulTools仓库中的屏幕截图截功能配合使用,可实现电脑长（宽）截屏

